AnimationClip class

A clip containing multiple tracks that animate a node.

Constructors

AnimationClip({required String name, required List<AnimationTrack> tracks, bool loop = false})

Properties

duration double
no setter
hashCode int
The hash code for this object.
no setterinherited
loop bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tracks List<AnimationTrack>
final

Methods

apply(Node node, double time) → void
isFinished(double time) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited