Vector3Track class

Animates a Vector3 property (position, scale).

Inheritance

Constructors

Vector3Track({required String targetProperty, required List<Keyframe<Vector3>> keyframes})

Properties

duration double
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
keyframes List<Keyframe<Vector3>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetProperty String
final

Methods

apply(Node node, double time) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited