Keyframe<T> class

A single keyframe in an animation track.

Constructors

Keyframe({required double time, required T value, EasingFunction easing = EasingFunction.linear})
const

Properties

easing → EasingFunction
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → double
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited