Skeleton class
A skeleton is a hierarchy of bones used for mesh deformation.
Constructors
-
Skeleton({required Bone root, required List<
Bone> bones}) - Skeleton.humanoid()
-
Creates a simple humanoid skeleton.
factory
Properties
Methods
-
findBone(
String name) → Bone? - Finds a bone by name.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited