VRElement class abstract

Base class for any object rendered in the VR scene.

Implementers

Constructors

VRElement({required Offset3D position, bool visible = true})

Properties

hashCode int
The hash code for this object.
no setterinherited
position Offset3D
Position in 3D world space.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visible bool
Whether this element is visible.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas, double screenX, double screenY, double depth, double scale) → void
Renders this element at the given projected screen position.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited