VRRing class
A ring/circle in VR space (rendered as an arc at its projected position).
Constructors
Properties
- color ↔ Color
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- position ↔ Offset3D
-
Position in 3D world space.
getter/setter pairinherited
- ringRadius → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → double
-
final
- visible ↔ bool
-
Whether this element is visible.
getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Canvas canvas, double screenX, double screenY, double depth, double scale) → void -
Renders this element at the given projected screen position.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited