VRCamera class

Legacy VR camera with spherical orientation (theta/phi). Used by the original neom_vr particle system. For new code, prefer CameraRig which uses Matrix4 + Quaternion.

Implemented types

Constructors

VRCamera({double theta = 0, double phi = 0, double fov = 1.2, double autoRotateSpeed = 0})

Properties

autoRotateSpeed double
getter/setter pair
fov double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
phi double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theta double
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
override
rotate(double dTheta, double dPhi) → void
override
toString() String
A string representation of this object.
inherited
update(double dt) → void
worldToCamera(Offset3D point) Offset3D

Operators

operator ==(Object other) bool
The equality operator.
inherited