ControllerState class

Represents the state of a VR controller (left or right hand).

Constructors

ControllerState({required ControllerHand hand, Transform3D? transform, bool triggerPressed = false, double triggerValue = 0, bool gripPressed = false, double gripValue = 0, bool primaryButtonPressed = false, bool secondaryButtonPressed = false, bool thumbstickPressed = false, Vector2? thumbstick, bool connected = false})

Properties

connected bool
getter/setter pair
forward → Vector3
no setter
gripPressed bool
getter/setter pair
gripValue double
getter/setter pair
hand ControllerHand
final
hashCode int
The hash code for this object.
no setterinherited
position → Vector3
no setter
primaryButtonPressed bool
getter/setter pair
ray → Ray
Ray from controller position in forward direction.
no setter
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondaryButtonPressed bool
getter/setter pair
thumbstick ↔ Vector2
getter/setter pair
thumbstickPressed bool
getter/setter pair
transform Transform3D
final
triggerPressed bool
getter/setter pair
triggerValue double
getter/setter pair
up → Vector3
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reset() → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited