dwellAcceleration property
Dwell acceleration factor applied each time the same target is dwell-selected consecutively (0.8 = 20% faster each time).
Implementation
double dwellAcceleration;
Dwell acceleration factor applied each time the same target is dwell-selected consecutively (0.8 = 20% faster each time).
double dwellAcceleration;