gazeGracePeriod property
Grace period in seconds: if the gaze briefly leaves the target for less than this, the dwell timer is preserved instead of reset.
Implementation
double gazeGracePeriod;
Grace period in seconds: if the gaze briefly leaves the target for less than this, the dwell timer is preserved instead of reset.
double gazeGracePeriod;