core/input/hand_state library

Classes

HandBone
Represents a bone connection between a parent and child joint in the hand skeleton.
HandState
Represents the tracked state of a hand with 26 joints following OpenXR standard.
MediaPipeHandDriver
Converts MediaPipe / MLKit 3D landmark coordinates to an OpenXR HandState.

Enums

HandJoint
26 joints per hand following the OpenXR hand tracking standard.