HandBone class

Represents a bone connection between a parent and child joint in the hand skeleton.

Constructors

HandBone(HandJoint parent, HandJoint child)
const

Properties

child HandJoint
final
hashCode int
The hash code for this object.
no setterinherited
parent HandJoint
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited