MediaPipeHandDriver class
Converts MediaPipe / MLKit 3D landmark coordinates to an OpenXR HandState.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
updateHandFromLandmarks(
HandState state, List< Vector3> landmarks) → void -
Maps a list of 21 MediaPipe 3D normalized landmark points
x, y, zto HandState.