volumeWidth property
Width of the tracked volume in meters at the reference distance.
Maps normalized image x (0..1) to -width/2, width/2.
Implementation
double volumeWidth;
Width of the tracked volume in meters at the reference distance.
Maps normalized image x (0..1) to -width/2, width/2.
double volumeWidth;