pointingRay property
Ray?
pointingRay
final
Pointing ray at the moment of the event (only for aim-related gestures).
Implementation
final Ray? pointingRay;
Pointing ray at the moment of the event (only for aim-related gestures).
final Ray? pointingRay;