landmarks property
21 landmarks in MediaPipe order. x/y are normalized image
coordinates (0..1), z is relative depth with the wrist as origin.
Implementation
final List<Vector3> landmarks;
21 landmarks in MediaPipe order. x/y are normalized image
coordinates (0..1), z is relative depth with the wrist as origin.
final List<Vector3> landmarks;