useIsolate property
Whether to use background Isolate for sensor fusion (default: false). Platforms without isolate support keep using main-thread fusion.
Implementation
final bool useIsolate;
Whether to use background Isolate for sensor fusion (default: false). Platforms without isolate support keep using main-thread fusion.
final bool useIsolate;