RotationTarget class abstract

Interface for anything that can receive rotation input.

Implementers

Constructors

RotationTarget()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recenter() → void
reset() → void
rotate(double dTheta, double dPhi) → void
setOrientation(double yaw, double pitch) → void
Sets absolute gaze angles (yaw, pitch) in radians.
setPitch(double pitch) → void
Sets absolute elevation (pitch) in radians.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited