AimAction class

The user is aiming with a hand ray; ray is the pointing ray in tracking space.

Inheritance

Constructors

AimAction({required ControllerHand hand, required Ray ray, bool active = true, DateTime? timestamp})

Properties

active bool
final
hand ControllerHand
final
hashCode int
The hash code for this object.
no setterinherited
ray → Ray
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited