VrInputAction class sealed
High-level, device-agnostic VR actions produced by fusing every available input channel (gaze, camera hand tracking, inertial walk-in-place, and ultrasonic gestures).
- Implementers
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited