VrInputSink class abstract interface

Sink passed to a VrInputDriver when it is attached to an arbiter.

A high-frequency driver should acquire one event, submit it, and release it in a finally block. emit is a convenient acquire/submit/release wrapper for discrete events.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acquire({required VrInputType type, String? targetId, Map<String, dynamic>? data, bool active = true}) VrInputEvent
emit({required VrInputType type, String? targetId, Map<String, dynamic>? data, bool active = true}) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release(VrInputEvent event) → void
submit(VrInputEvent event) bool
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited