core/input/vr_input_event_bus library

Classes

VrInputEvent
Unified spatial input event.
VrInputEventBus
Central Event Bus for unified multimodal spatial input in VRlizate.

Enums

VrInputSource
Hardware or software source that originated the input event.
VrInputType
Canonical input interaction types across VRlizate XR experiences.