VrInputEventBus class

Central Event Bus for unified multimodal spatial input in VRlizate.

Decouples raw hardware sensors (IMU, camera, microphone, ultrasound, remote phone) from 3D scenes, allowing any scene to respond to spatial inputs agnostically.

Properties

hashCode int
The hash code for this object.
no setterinherited
onEvent Stream<VrInputEvent>
Stream of all spatial input events.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

emit(VrInputEvent event) → void
Emits a new spatial input event to all subscribers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onSource(VrInputSource source) Stream<VrInputEvent>
Convenience stream filtered by VrInputSource.
onType(VrInputType type) Stream<VrInputEvent>
Convenience stream filtered by VrInputType.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance VrInputEventBus
no setter