emit method
Emits a new spatial input event to all subscribers.
Implementation
void emit(VrInputEvent event) {
_controller.add(event);
}
Emits a new spatial input event to all subscribers.
void emit(VrInputEvent event) {
_controller.add(event);
}