core/input/wifi_sensing library
Classes
- CsiFrame
- A simulated raw Channel State Information frame. Represents OFDM subcarrier amplitudes affected by human movement.
- WifiSensingSystem
- SOTA WiFi Sensing Engine that processes raw CSI frames in a background Isolate to track movement, presence, and vitals (respiration) of human subjects.
- WifiTrackedSubject
- Represents a physical entity tracked in the room through WiFi CSI (Channel State Information).