WifiSensingSystem class

SOTA WiFi Sensing Engine that processes raw CSI frames in a background Isolate to track movement, presence, and vitals (respiration) of human subjects.

Constructors

WifiSensingSystem()

Properties

hashCode int
The hash code for this object.
no setterinherited
isActive bool
getter/setter pair
onSubjectsUpdated Stream<List<WifiTrackedSubject>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trackedSubjects List<WifiTrackedSubject>
final

Methods

dispose() → void
feedRawCsi(CsiFrame frame) → void
Feeds simulated raw CSI frame into the background Isolate for processing
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
start() Future<void>
Initializes the background processing Isolate for CSI data processing.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited