VrControlDescriptor class
One visual and semantic control exposed by a remote device.
Constructors
- VrControlDescriptor({required String id, required String label, required VrControlKind kind, required double x, required double y, double width = 0.18, double height = 0.12})
-
factory
-
VrControlDescriptor.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- height → double
-
final
- id → String
-
final
- kind → VrControlKind
-
final
- label → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → double
-
final
- x → double
-
Center and size in normalized portrait-screen coordinates.
final
- y → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override