VrControllerMessageCodec class

Newline-friendly JSON codec used by the reference socket transport.

Constructors

VrControllerMessageCodec()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

decode(String encoded) → VrControllerMessage
encode(VrControllerMessage message) → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited