VrHelloMessage class final

Inheritance

Constructors

VrHelloMessage({int protocolVersion = vrControllerProtocolVersion, required String sessionToken, required VrDeviceRole role, String? deviceName})
VrHelloMessage.fromJson(Map<String, dynamic> json)
factory

Properties

deviceName → String?
final
hashCode → int
The hash code for this object.
no setterinherited
kind → String
no setteroverride
protocolVersion → int
final
role → VrDeviceRole
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionToken → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited