VrPingMessage class final

Inheritance

Constructors

VrPingMessage({required int id, required int sentTimestampMicroseconds})
const
VrPingMessage.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
final
kind → String
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentTimestampMicroseconds → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited