ProjectedPoint class

Projected 2D point with depth info for z-sorting.

Constructors

ProjectedPoint({required double screenX, required double screenY, required double depth, bool visible = true})
const

Properties

depth double
final
hashCode int
The hash code for this object.
no setterinherited
offset Offset
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenX double
final
screenY double
final
visible bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited