core/rendering/vr_gpu_target_descriptor library

Classes

VrExternalRenderTargetDescriptor
Immutable descriptor defining the properties of an external GPU render target.

Enums

VrGpuBackend
GPU backend types supported for external render target presentation.
VrGpuTextureFormat
Common texture pixel formats used by VR swapchains and render targets.