Grabbable class

Makes a node grabbable via controller grip or pinch.

Constructors

Grabbable({required Node node, double maxGrabDistance = 2.0, void onGrabStart(Node node)?, void onGrabEnd(Node node)?, void onRelease(Node node, Vector3 velocity)?})

Properties

grabbedBy ↔ ControllerHand?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isGrabbed ↔ bool
getter/setter pair
maxGrabDistance ↔ double
Maximum grab distance.
getter/setter pair
node → Node
final
onGrabEnd ↔ void Function(Node node)?
getter/setter pair
onGrabStart ↔ void Function(Node node)?
getter/setter pair
onRelease ↔ void Function(Node node, Vector3 velocity)?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Releases the node, optionally with throw velocity.
toString() → String
A string representation of this object.
inherited
tryGrab(ControllerState controller) → bool
Attempts to grab this node from a controller.
updateGrab(ControllerState controller) → void
Updates the grabbed node position to follow the controller.

Operators

operator ==(Object other) → bool
The equality operator.
inherited