Pointable class
Makes a node respond to pointer hover and click events.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverColor ↔ Color
-
Visual highlight color when hovered.
getter/setter pair
- isHovered ↔ bool
-
getter/setter pair
- isPressed ↔ bool
-
getter/setter pair
- node → Node
-
final
- onHoverEnter ↔ void Function(Node node)?
-
getter/setter pair
- onHoverExit ↔ void Function(Node node)?
-
getter/setter pair
- onPress ↔ void Function(Node node, RaycastHit hit)?
-
getter/setter pair
- onRelease ↔ void Function(Node node)?
-
getter/setter pair
- pressColor ↔ Color
-
Visual highlight color when pressed.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
press(
RaycastHit hit) → void -
release(
) → void -
toString(
) → String -
A string representation of this object.
inherited
-
updateHover(
bool hovering) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited