GltfResult class

Result of parsing a glTF file.

Constructors

GltfResult({required Node root, required List<MeshNode> meshes, required List<VRMaterial> materials})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
materials List<VRMaterial>
final
meshes List<MeshNode>
final
root Node
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited