unitPlane property
1 m × 1 m horizontal quad centered on the origin, facing +Y.
Implementation
static final PlaneGeometry unitPlane = PlaneGeometry(width: 1.0, height: 1.0);
1 m × 1 m horizontal quad centered on the origin, facing +Y.
static final PlaneGeometry unitPlane = PlaneGeometry(width: 1.0, height: 1.0);