ShadowConfig class

Shadow configuration for a light source.

Constructors

ShadowConfig({int resolution = 512, double bias = 0.005, double darkness = 0.5, double maxDistance = 30, bool enabled = true})

Properties

bias double
Shadow bias to prevent self-shadowing artifacts.
getter/setter pair
darkness double
Shadow darkness (0 = invisible, 1 = fully black).
getter/setter pair
enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
maxDistance double
Maximum shadow distance from camera.
getter/setter pair
resolution int
Shadow map resolution (higher = sharper shadows, more expensive).
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited