ShadowRenderer class
Simple shadow renderer that projects shadows onto the ground plane. Uses a simplified shadow map approach for Canvas rendering.
Constructors
- ShadowRenderer({ShadowConfig? config})
Properties
- config → ShadowConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renderShadows(
Canvas canvas, Matrix4 viewProjection, Light light, List< Node> nodes, double groundY) → void - Renders ground-plane shadows for all nodes illuminated by a directional light.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited