repeatU property
How many times the image repeats across the mesh's U and V range
(1 = once). A 20 m floor plane with a 2 m tile uses repeatU = 10.
Implementation
double repeatU;
How many times the image repeats across the mesh's U and V range
(1 = once). A 20 m floor plane with a 2 m tile uses repeatU = 10.
double repeatU;