AnimationClip class
A clip containing multiple tracks that animate a node.
Constructors
-
AnimationClip({required String name, required List<
AnimationTrack> tracks, bool loop = false})
Properties
Methods
-
apply(
Node node, double time) → void -
isFinished(
double time) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited