Skeleton class

A skeleton is a hierarchy of bones used for mesh deformation.

Constructors

Skeleton({required Bone root, required List<Bone> bones})
Skeleton.humanoid()
Creates a simple humanoid skeleton.
factory

Properties

bones → List<Bone>
final
hashCode → int
The hash code for this object.
no setterinherited
root → Bone
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skinningMatrices → List<Matrix4>
Collects all skinning matrices for shader upload.
no setter

Methods

findBone(String name) → Bone?
Finds a bone by name.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited