VRConnection class

A line connecting two VR elements.

Constructors

VRConnection({required VRElement a, required VRElement b, Color color = const Color(0x80FFFFFF), double strokeWidth = 0.5})
const

Properties

a VRElement
final
b VRElement
final
color Color
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeWidth double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited