VRScene class
A scene containing VR elements that can be rendered stereoscopically.
- Implemented types
Constructors
- VRScene({Color backgroundColor = const Color(0xFF0A0A1A), LinearGradient? backgroundGradient})
Properties
- backgroundColor ↔ Color
-
Background color.
getter/setter pair
- backgroundGradient ↔ LinearGradient?
-
Background gradient (overrides backgroundColor if set).
getter/setter pair
-
connections
→ List<
VRConnection> -
final
-
elements
→ List<
VRElement> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addConnection(
VRConnection connection) → void -
addElement(
VRElement element) → void -
clear(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
renderEye(
Canvas canvas, Size viewportSize, VRCamera camera, StereoscopicProjection projection, bool isLeftEye) → void -
Renders the scene for a single eye viewport.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited