VrRay class
A ray defined by origin and direction. Named VrRay to avoid collision with vector_math's Ray.
Constructors
- VrRay({required Vector3 origin, required Vector3 direction})
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pointAt(
double t) → Vector3 - Returns a point along the ray at distance t.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited