VrRemoteTouchpadDriver class
Converts normalized coordinates from a remote phone into navigation input.
The payload map is reused. Consumers must copy any values they need after synchronous event dispatch.
- Implemented types
Constructors
- VrRemoteTouchpadDriver({double deadZone = 0.12})
Properties
- axisX → double
-
no setter
- axisY → double
-
no setter
- deadZone → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
no setter
- isAttached → bool
-
no setter
- priority → VrInputPriority
-
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → VrInputSource
-
no setteroverride
Methods
-
attach(
VrInputSink sink) → void -
override
-
detach(
) → void -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updateTouch(
double? x, double? y) → bool -
Emits joystick-style navigation from normalized coordinates in
0, 1.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- axisXKey → const String
- axisYKey → const String
- normalizedXKey → const String
- normalizedYKey → const String