HandJoint enum
26 joints per hand following the OpenXR hand tracking standard.
Values
- palm → const HandJoint
- wrist → const HandJoint
- thumbMetacarpal → const HandJoint
- thumbProximal → const HandJoint
- thumbDistal → const HandJoint
- thumbTip → const HandJoint
- indexMetacarpal → const HandJoint
- indexProximal → const HandJoint
- indexIntermediate → const HandJoint
- indexDistal → const HandJoint
- indexTip → const HandJoint
- middleMetacarpal → const HandJoint
- middleProximal → const HandJoint
- middleIntermediate → const HandJoint
- middleDistal → const HandJoint
- middleTip → const HandJoint
- ringMetacarpal → const HandJoint
- ringProximal → const HandJoint
- ringIntermediate → const HandJoint
- ringDistal → const HandJoint
- ringTip → const HandJoint
- littleMetacarpal → const HandJoint
- littleProximal → const HandJoint
- littleIntermediate → const HandJoint
- littleDistal → const HandJoint
- littleTip → const HandJoint
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited