HandState class
Represents the tracked state of a hand with 25 joints.
Constructors
-
HandState({required ControllerHand hand, Map<
HandJoint, Vector3> ? joints, bool tracked = false})
Properties
- hand → ControllerHand
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexTipPosition → Vector3?
-
no setter
- isFist → bool
-
Whether the hand is making a fist (all tips close to palm).
no setter
- isPinching → bool
-
Whether the user is performing a pinch gesture.
no setter
- isPointing → bool
-
Whether the index finger is extended (pointing).
no setter
-
joints
→ Map<
HandJoint, Vector3> -
final
- palmPosition → Vector3?
-
no setter
- pinchDistance → double
-
Distance between thumb tip and index tip.
no setter
- pointingRay → Ray?
-
Ray from palm through index tip (for pointing/selection).
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbTipPosition → Vector3?
-
no setter
- tracked ↔ bool
-
getter/setter pair
Methods
-
joint(
HandJoint j) → Vector3? -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited