HandGestureEvent class

A recognized gesture event emitted by HandGestureRecognizer.

Constructors

HandGestureEvent({required ControllerHand hand, required HandGesture gesture, DateTime? timestamp, Ray? pointingRay})

Properties

gesture HandGesture
final
hand ControllerHand
final
hashCode int
The hash code for this object.
no setterinherited
pointingRay → Ray?
Pointing ray at the moment of the event (only for aim-related gestures).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited