canStart property
bool
get
canStart
Whether a registered platform backend or an injected sensor source can be started. This does not claim that hardware is present or sending data.
Implementation
bool get canStart =>
VrSensorCapabilities.supportsDeviceMotion ||
gyroscopeStreamOverride != null ||
accelerometerStreamOverride != null;