MoveAction class

Continuous locomotion request in units per second along the head's ground-projected forward direction (0 = stop).

Inheritance

Constructors

MoveAction({required double speed, DateTime? timestamp})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
speed double
final
timestamp DateTime
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited