MoveAction class
Continuous locomotion request in units per second along the head's ground-projected forward direction (0 = stop).
- Inheritance
-
- Object
- VrInputAction
- MoveAction
Constructors
- MoveAction({required double speed, DateTime? timestamp})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited