SelectAction class
A confirmed selection ("click") on a target, from any channel. targetId is null when the action came from a channel without a ray target (e.g. ultrasonic push with no gaze hit).
- Inheritance
-
- Object
- VrInputAction
- SelectAction
Constructors
- SelectAction({String? targetId, required String source, DateTime? timestamp})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String
-
Channel that produced the selection:
gaze,hand,ultrasonic, ortap.final - targetId → String?
-
final
- timestamp → DateTime
-
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited