Optional per-driver priority override.
Most drivers inherit the stable priority of their VrInputDriver.source. A specialized driver can implement this interface when the same hardware source exposes interaction modes with different arbitration semantics.
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- priority → VrInputPriority
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited