active property
bool
get
active
Whether the source is actively manipulated.
A joystick outside its dead zone or a touch-down is active. A centered joystick or touch-up is inactive and does not extend arbitration hysteresis.
Implementation
bool get active => _active;