VrInputSource enum
Hardware or software source that originated the input event.
Values
- templeTap → const VrInputSource
-
Temple tap detection via IMU accelerometer spike.
- remotePhone → const VrInputSource
-
2nd smartphone 3DoF laser remote controller.
- voice → const VrInputSource
-
Hands-free voice recognition / Itzli AI assistant.
- gaze → const VrInputSource
-
Center gaze dwell pointer.
- sonar → const VrInputSource
-
Ultrasonic Doppler acoustic gesture (19.2 kHz).
- cameraHand → const VrInputSource
-
Computer vision optical hand tracking.
- touch → const VrInputSource
-
Direct touchscreen touch.
- gamepad → const VrInputSource
-
Bluetooth, USB, or platform gamepad.
- externalPeripheral → const VrInputSource
-
Community-provided peripheral without a more specific source.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VrInputSource> - A constant List of the values in this enum, in order of their declaration.