Aabb class
Axis-aligned bounding box for frustum culling.
Constructors
- Aabb({Vector3? min, Vector3? max})
- Aabb.fromCenterExtents(Vector3 center, Vector3 extents)
Properties
- center → Vector3
-
no setter
- extents → Vector3
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- max ↔ Vector3
-
getter/setter pair
- min ↔ Vector3
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → Vector3
-
no setter
Methods
-
containsPoint(
Vector3 point) → bool -
expandToInclude(
Vector3 point) → void -
expandToIncludeAabb(
Aabb other) → void -
intersectsAabb(
Aabb other) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transformed(
Matrix4 matrix) → Aabb - Transforms this AABB by a matrix, producing a new AABB that encloses the result.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited