VrControllerProfile class
Description sent once by the child so the visor can build a controller UI.
Constructors
-
VrControllerProfile({int protocolVersion = vrControllerProtocolVersion, required String deviceId, required String deviceName, VrControllerHandedness handedness = VrControllerHandedness.unspecified, required double widthMeters, required double heightMeters, required List<
VrControlDescriptor> controls}) -
factory
-
VrControllerProfile.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
controls
→ List<
VrControlDescriptor> -
final
- deviceId → String
-
final
- deviceName → String
-
final
- handedness → VrControllerHandedness
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- heightMeters → double
-
final
- protocolVersion → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- widthMeters → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override