VrInputEventSnapshot class
Immutable copy of a potentially pooled VrInputEvent.
Constructors
- VrInputEventSnapshot.fromEvent(VrInputEvent event)
-
Copies every payload value synchronously before an async send can retain it.
factory
-
VrInputEventSnapshot.fromJson(Map<
String, dynamic> json) -
factory
Properties
- active → bool
-
final
-
data
→ Map<
String, dynamic> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → VrInputSource
-
final
- targetId → String?
-
final
- timestampMicrosecondsSinceEpoch → int
-
final
- type → VrInputType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toEvent(
) → VrInputEvent -
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited