VrRemoteImuController class
Child-side IMU producer for a low-cost smartphone controller.
Gyroscope samples are integrated into a recenterable 3DoF quaternion. The accelerometer is transmitted for motion and diagnostics, but is deliberately not integrated into position because consumer IMU translation drifts fast.
Constructors
-
VrRemoteImuController({required VrControllerTransport transport, required VrControllerProfile profile, VrImuScreenOrientation screenOrientation = VrImuScreenOrientation.landscapeLeft, Duration samplingPeriod = const Duration(milliseconds: 8), Duration minimumSendInterval = const Duration(milliseconds: 16), Stream<
GyroscopeEvent> ? gyroscopeStreamOverride, Stream<AccelerometerEvent> ? accelerometerStreamOverride, void onError(Object error, StackTrace stackTrace)?})
Properties
-
accelerometerStreamOverride
→ Stream<
AccelerometerEvent> ? -
final
-
no setter
-
gyroscopeStreamOverride
→ Stream<
GyroscopeEvent> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isRunning → bool
-
no setter
- minimumSendInterval → Duration
-
final
- onError → void Function(Object error, StackTrace stackTrace)?
-
final
- orientation → Quaternion
-
no setter
- profile → VrControllerProfile
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- samplingPeriod → Duration
-
final
- screenOrientation → VrImuScreenOrientation
-
final
- sequence → int
-
no setter
- transport → VrControllerTransport
-
final
Methods
-
clearTouch(
{bool sendImmediately = true}) → void -
flush(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
recenter(
{bool sendImmediately = true}) → void - Resets the current physical pose to the logical controller-forward pose.
-
sendCurrentState(
) → void -
setButtonsBitset(
int value, {bool sendImmediately = true}) → void -
setTouch(
double x, double y, {bool sendImmediately = true}) → void -
start(
) → Future< void> -
stop(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited