RenderPass class
Render pass that traverses the scene and renders to a canvas. Handles: frustum culling, depth sorting, lighting injection, background.
Constructors
- RenderPass({required Scene scene, required CameraRig cameraRig})
Properties
- cameraRig → CameraRig
-
final
- culledCount → int
-
no setter
-
distortionCoefficients
↔ List<
double> -
Coefficients for the radial distortion (default is Cardboard V1
0.441, 0.156)getter/setter pair - enableChromaticAberration ↔ bool
-
Whether to apply RGB color splitting dispersion correction in distortion
getter/setter pair
- enableLensDistortion ↔ bool
-
Whether to apply radial lens distortion correction.
getter/setter pair
- fsrScale ↔ double
-
FSR (FidelityFX Super Resolution) simulation: scaling ratio of offline viewport
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- leftAtwMatrix ↔ Matrix4?
-
Transformation matrices for Asynchronous Time Warp (ATW)
getter/setter pair
- renderedCount → int
-
no setter
- rightAtwMatrix ↔ Matrix4?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scene → Scene
-
final
- useATWFallback ↔ bool
-
Trigger to skip rendering and warp last frame's cached images directly
getter/setter pair
Methods
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Canvas canvas, Size viewportSize, {required Matrix4 viewProjection}) → void - Renders the scene for one eye.
-
renderMono(
Canvas canvas, Size size) → void - Renders monoscopic.
-
renderStereo(
Canvas canvas, Size fullSize) → void - Renders stereo: left eye then right eye, side by side. Renders offline, then applies FFR/FSR scaling, chromatic aberration, and ATW warping. Reuses cached image buffers if useATWFallback is true.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited