ShaderRegistry class
Registry of available shader programs.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void -
get(
String name) → ShaderProgram? - Gets a shader by name.
-
loadAll(
) → Future< void> - Loads all registered shaders from assets.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
ShaderProgram shader) → void - Registers a shader program.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited