DebugOverlay class

Debug overlay that displays performance metrics in VR.

Constructors

DebugOverlay({bool enabled = false, bool showFps = true, bool showNodeCount = true, bool showCullingStats = true, bool showCameraInfo = false})

Properties

enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCameraInfo bool
getter/setter pair
showCullingStats bool
getter/setter pair
showFps bool
getter/setter pair
showNodeCount bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
render(Canvas canvas, Size size, VREngine engine) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited