BloomEffect class

Simple bloom effect applied as a post-process overlay. Draws bright areas with gaussian blur to simulate light bleed.

Constructors

BloomEffect({double intensity = 0.5, double threshold = 0.7, double radius = 20, bool enabled = true})

Properties

enabled bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
intensity double
getter/setter pair
radius double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold double
getter/setter pair

Methods

apply(Canvas canvas, Size size) → void
Applies bloom to the canvas by drawing a blurred overlay of bright areas.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited