RaycastHit class

Result of a raycast hit.

Constructors

RaycastHit({required Node node, required Vector3 point, required double distance, required Vector3 normal})
const

Properties

distance double
final
hashCode int
The hash code for this object.
no setterinherited
node Node
final
normal → Vector3
final
point → Vector3
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited