DepthDisplacedGeometry class
A 3D geometry generated by displacing a grid mesh using a depth map list.
Constructors
Properties
- aabb → Aabb
-
no setterinherited
-
depthMap
→ List<
double> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double
-
final
- heightSegments → int
-
final
-
indices
→ List<
int> -
Triangle indices (3 per triangle).
finalinherited
- maxDisplacement → double
-
final
-
normals
→ List<
Vector3> -
Vertex normals (3 floats per vertex).
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- triangleCount → int
-
no setterinherited
-
uvs
→ List<
Vector2> -
UV coordinates (2 floats per vertex).
finalinherited
- vertexCount → int
-
no setterinherited
-
vertices
→ List<
Vector3> -
Vertex positions (3 floats per vertex).
finalinherited
- width → double
-
final
- widthSegments → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited