Geometry class
Raw vertex data for a 3D geometry.
- Implementers
Constructors
Properties
- aabb → Aabb
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
indices
→ List<
int> -
Triangle indices (3 per triangle).
final
-
normals
→ List<
Vector3> -
Vertex normals (3 floats per vertex).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- triangleCount → int
-
no setter
-
uvs
→ List<
Vector2> -
UV coordinates (2 floats per vertex).
final
- vertexCount → int
-
no setter
-
vertices
→ List<
Vector3> -
Vertex positions (3 floats per vertex).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited