VRMaterial class

Material defines the visual appearance of a mesh surface.

Implementers

Constructors

VRMaterial({Color color = const Color(0xFFCCCCCC), Color emissive = const Color(0xFF000000), double opacity = 1.0, double metallic = 0.0, double roughness = 0.8, bool doubleSided = false, bool wireframe = false, BlendMode blendMode = BlendMode.srcOver})

Properties

blendMode BlendMode
getter/setter pair
color Color
getter/setter pair
doubleSided bool
getter/setter pair
emissive Color
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isTransparent bool
no setter
metallic double
getter/setter pair
opacity double
getter/setter pair
roughness double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireframe bool
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toPaint({double lightFactor = 1.0}) Paint
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

glow({Color color = const Color(0xFF00CED1), double intensity = 1.0}) VRMaterial
Emissive glow material.
unlit({Color color = const Color(0xFFFFFFFF), double opacity = 1.0}) VRMaterial
Basic unlit material.