SphereGeometry class
Properties
-
aabb
→ Aabb
-
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
indices
→ List<int>
-
Triangle indices (3 per triangle).
finalinherited
-
normals
→ List<Vector3>
-
Vertex normals (3 floats per vertex).
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
triangleCount
→ int
-
no setterinherited
-
uvs
→ List<Vector2>
-
UV coordinates (2 floats per vertex).
finalinherited
-
vertexCount
→ int
-
no setterinherited
-
vertices
→ List<Vector3>
-
Vertex positions (3 floats per vertex).
finalinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited