Scene class

Root of the scene graph. Contains the environment and all nodes.

Constructors

Scene({Color backgroundColor = const Color(0xFF0A0A1A), Color ambientColor = const Color(0xFF202030), double fogDensity = 0, Color fogColor = const Color(0xFF000000)})

Properties

ambientColor Color
getter/setter pair
backgroundColor Color
getter/setter pair
fogColor Color
getter/setter pair
fogDensity double
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
lights List<Light>
Collects all lights in the scene tree.
no setter
root Node
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleNodes List<Node>
Collects all visible nodes.
no setter

Methods

add(Node node) → void
clear() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(Node node) → void
toString() String
A string representation of this object.
inherited
update(double dt) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited