Offset3D class

Constructors

Offset3D(double x, double y, double z)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
length double
no setter
normalized Offset3D
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
final
y double
final
z double
final

Methods

cross(Offset3D other) Offset3D
dot(Offset3D other) double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rotateX(double angle) Offset3D
Rotates this point around X axis (vertical camera rotation).
rotateY(double angle) Offset3D
Rotates this point around Y axis (horizontal camera rotation).
toString() String
A string representation of this object.
override

Operators

operator *(double s) Offset3D
operator +(Offset3D other) Offset3D
operator -(Offset3D other) Offset3D
operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromSpherical(double theta, double phi, double radius) Offset3D
Converts spherical coordinates (theta, phi, radius) to cartesian.